@@ -286,7 +286,7 @@ class CommandConfig:
     allow_backtrack: Bool = ConfigItem(True, bool)
 
     #: How the default long form that is added for Option/Flag/Counter/etc. Parameters should handle underscores/dashes
-    option_name_mode: OptionNameMode = ConfigItem(OptionNameMode.UNDERSCORE, OptionNameMode)
+    option_name_mode: OptionNameMode = ConfigItem(OptionNameMode.DASH, OptionNameMode)
 
     #: Whether ambiguous combinations of positional choices should result in an :class:`.AmbiguousParseTree` error
     reject_ambiguous_pos_combos: Bool = ConfigItem(False, bool)  # EXPERIMENTAL
